.. :changelog:

History
-------

0.3.0 (2015-10-08)
------------------
* python 3 print fix (thanks Mike Nawrocki)
* add set_next_boot and change_boot_order_request (thanks John L. Villalovos)

0.1.0 (2015-08-09)
---------------------

* First release on PyPI.
